package com.diagbot.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.EntryNumDTO;
import com.diagbot.dto.HomePageNumDTO;
import com.diagbot.dto.LevelStatisticsDTO;
import com.diagbot.dto.LevelStatisticsTZDTO;
import com.diagbot.util.ExcelUtils;
import com.diagbot.vo.FilterOrderVO;
import com.diagbot.vo.FilterPageVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Description: 报表导出装饰层
 * @author: gaodm
 * @time: 2020/6/18 10:41
 */
@Component
public class ConsoleExportFacade {

    @Autowired
    private ConsoleFacade consoleFacade;


    /**
     * 病案首页合格率占比
     *
     * @param filterOrderVO
     * @return
     */
    public void homePageLevelExport(HttpServletResponse response, FilterOrderVO filterOrderVO) {
        List<HomePageNumDTO> res = consoleFacade.homePageLevelStatistics(filterOrderVO);
        String fileName = "病案首页合格率占比.xls";
        ExcelUtils.exportExcel(res, null, "sheet1", HomePageNumDTO.class, fileName, response, 12.8f);
    }

    /**
     * 条目缺陷占比（内页）
     *
     * @param filterPageVO
     * @return
     */
    public void entryGroupByEntryExport(HttpServletResponse response, FilterPageVO filterPageVO) {
        filterPageVO.setCurrent(1L);
        filterPageVO.setSize(Long.MAX_VALUE);
        filterPageVO.setSearchCount(false);
        IPage<EntryNumDTO> page = consoleFacade.entryGroupByEntryInnerPage(filterPageVO);
        String fileName = "条目缺陷占比.xls";
        ExcelUtils.exportExcel(page.getRecords(), null, "sheet1", EntryNumDTO.class, fileName, response, 12.8f);
    }

    /**
     * 各科室缺陷占比（组合）
     *
     * @param filterOrderVO
     * @return
     */
    public void levelExport(HttpServletResponse response, FilterOrderVO filterOrderVO) {
        List<LevelStatisticsDTO> records = consoleFacade.levelStatistics(filterOrderVO);
        String fileName = "各科室缺陷占比.xls";
        ExcelUtils.exportExcel(records, null, "sheet1", LevelStatisticsDTO.class, fileName, response, 12.8f);
    }

    /**
     * 各科室缺陷占比（组合）-台州
     *
     * @param filterOrderVO
     * @return
     */
    public void levelExport_TZ(HttpServletResponse response, FilterOrderVO filterOrderVO) {
        List<LevelStatisticsTZDTO> records = consoleFacade.levelStatisticsByDeptClass_TZ(filterOrderVO);
        String fileName = "各科室缺陷占比-台州.xls";
        ExcelUtils.exportExcel(records, null, "sheet1", LevelStatisticsTZDTO.class, fileName, response, 12.8f);
    }
}
